@@ -1,3 +1,4 @@
+
 if ($m_nRight <= 1) {
     my $trlogin  = translate('login');
     my $password = translate('password');
@@ -7,6 +8,7 @@ if ($m_nRight <= 1) {
     my $right_passwort_text = translate('right_passwort_text');
     my $wrong_passwort_text = translate('wrong_passwort_text');
     my $authen ='';
+
     eval(q{
 	my $right_captcha_text = translate("right_captcha_text");
 	my $wrong_captcha_text = translate("wrong_captcha_text");
@@ -22,7 +24,7 @@ if ($m_nRight <= 1) {
         <input type="text" size="5" data-regexp="|.'/^.{3}$/'.qq|" data-error="$wrong_captcha_text" data-right="$right_captcha_text"  name="captcha"/>|;
        });
     $m_sContent .= div({align => 'center'}, translate('Codenotcheckedfileerror')) if $m_nSkipCaptch eq 0;
-    $m_sContent .= div({align => 'center'}, translate('Failedcodeexpired'))          if $m_nSkipCaptch eq -1;
+    $m_sContent .= div({align => 'center'}, translate('Codenotcheckedfileerror'))          if $m_nSkipCaptch eq -1;
     $m_sContent .= div({align => 'center'}, translate('Failednotindatabase'))       if $m_nSkipCaptch eq -2;
     $m_sContent .= div({align => 'center'}, translate('Failedinvalidcode'))          if $m_nSkipCaptch eq -3;
 $m_sContent .= qq(
