@@ -1,37 +1,37 @@
 $VAR1 = {
-          'admin' => {
-                       'firstname' => 'Dirk',
-                       'password' => 'testpass',
-                       'email' => 'dirk.lze@gmail.com',
-                       'name' => 'Lindner'
-                     },
           'translate' => '/var/www/cgi-bin/config/translate.pl',
-          'language' => 'en',
-          'database' => {
-                          'host' => 'localhost',
-                          'password' => 'wertvoll',
-                          'name' => 'LZE',
-                          'CurrentPass' => 'wertvoll',
-                          'CurrentHost' => 'localhost',
-                          'user' => 'root',
-                          'CurrentDb' => 'LZE',
-                          'CurrentUser' => 'root'
-                        },
+          'scriptAlias' => 'cgi-bin',
+          'version' => '0.7',
+          'floodtime' => 10,
           'config' => '/var/www/cgi-bin/config/settings.pl',
+          'admin' => {
+                       'email' => 'dirk.lze@gmail.com',
+                       'firstname' => 'Dirk',
+                       'name' => 'Lindner',
+                       'password' => 'testpass'
+                     },
           'cgi' => {
-                     'DocumentRoot' => '/var/www/htdocs',
-                     'cookiePath' => '/',
+                     'alias' => 'cgi-bin',
                      'style' => 'mysql',
+                     'title' => 'MySQL::Admin',
+                     'DocumentRoot' => '/var/www/htdocs',
+                     'bin' => '/var/www/cgi-bin',
                      'expires' => '+1y',
                      'serverName' => 'http://localhost',
-                     'title' => 'MySQL::Admin',
-                     'alias' => 'cgi-bin',
-                     'bin' => '/var/www/cgi-bin'
+                     'cookiePath' => '/'
                    },
-          'scriptAlias' => 'cgi-bin',
           'actions' => '/var/www/cgi-bin/config/actions.pl',
-          'floodtime' => 10,
+          'database' => {
+                          'CurrentPass' => 'wertvoll',
+                          'name' => 'LZE',
+                          'host' => 'localhost',
+                          'password' => 'wertvoll',
+                          'CurrentUser' => 'root',
+                          'user' => 'root',
+                          'CurrentHost' => 'localhost',
+                          'CurrentDb' => 'LZE'
+                        },
           'session' => '/var/www/cgi-bin/config/session.pl',
-          'version' => '0.69'
+          'language' => 'en'
         };
 $m_hrSettings =$VAR1;
\ No newline at end of file
