@@ -11,13 +11,13 @@ $VAR1 = {
                     'table' => 'Table',
                     'editmysqluserrights' => 'Rights',
                     'show' => 'Show',
-                    'type' => 'type',
+                    'type' => 'Type',
                     'optimize' => 'Optimize',
                     'newcol' => 'New Column',
-                    'edittableprops' => 'Database',
+                    'edittableprops' => 'Table',
                     'rename' => 'Rename',
                     'database' => 'Database',
-                    'collation' => 'collation',
+                    'collation' => 'Collation',
                     'databases' => 'Databases',
                     'wrong_passwort_text' => 'The password must be at least 6 characters in length.',
                     'edit' => 'Edit',
@@ -41,11 +41,11 @@ $VAR1 = {
                     'changecurrentdb' => 'Change Database connection',
                     'insertafter' => 'After',
                     'indexover' => 'Index over',
-                    'wrong_username_text' => 'The password must be at least 3 characters in length and can only contain letters or digits.',
-                    'changeautoincrementvalue' => 'Database',
-                    'createnewtable' => 'Database',
+                    'wrong_username_text' => 'The Username must be at least 3 characters in length and can only contain letters or digits.',
+                    'changeautoincrementvalue' => 'Edit Table',
+                    'createnewtable' => 'Tables',
                     'fields' => 'Fields',
-                    'daten' => 'data',
+                    'daten' => 'Data',
                     'delete' => 'Delete',
                     'export' => 'Export',
                     'showvariables' => 'Variables',
@@ -91,25 +91,33 @@ $VAR1 = {
                     'sqlsearch' => 'Search',                
                     'sqleditor' => 'Execute Sql',
                     'new' => 'New',
+                    'ShowTableDetails' => 'Details',
+		    'DropTable'=> 'Tables',
+		    'DropDatabase'=> 'Databases',
+		    'DeleteEntry'=> 'Table',
+		    'SaveRights'=> 'Rights',		    
+		    'codenotcheckedfileerror'=> '',
+		    'failednotindatabase'=> '',
+		    'failedinvalidcode'=> 'Failed invalid code',
                   },
           'de' => {
                     'host' => 'host',
-                    'right_username_text' => 'Der Benutzername darf nur ziffern und Buchstaben enthalten.',
-                    'showprocesslist' => 'Processlist',
+                    'right_username_text' => 'Ok',
+                    'showprocesslist' => 'Processe',
                     'showtable' => 'Tabelle',
                     'createtable' => 'Tabelle',
                     'showcreateuser' => 'Benutzer',
                     'welcome' => 'Willkommen',
-                    'field' => 'field',
+                    'field' => 'Feld',
                     'showchangecurrentdb' => 'Datenbank wechseln',
                     'register' => 'Registrieren',
                     'starttable' => 'am Anfang',
-                    'rights' => 'rights',
+                    'rights' => 'Rechte',
                     'search' => 'Suchen',
                     'showsqleditor' => 'SQL Ausführen',
                     'unselect_all' => 'Auswahl aufheben',
                     'shownewentry' => 'Neuer Eintrag',
-                    'user' => 'user',
+                    'user' => 'Benutzer',
                     'reg' => 'Registrieren',
                     'showcreatedatabase' => 'Datenbank',
                     'select_all' => 'Alle ausw&#228;hlen',
@@ -139,7 +147,7 @@ $VAR1 = {
                     'export' => 'Exportieren',
                     'optimizetable' => 'Optimieren',
                     'indexover' => 'Index &#252;ber',
-                    'wrong_username_text' => 'Muss zwischen 3 und 20 zeichen lang sein.',
+                    'wrong_username_text' => 'Der Benutzername muss mindestens 3 Zeichen lange sein und darf nur Ziffern und Buchstaben enthalten.',
                     'changecurrentdb' => 'Benutzer wechseln',
                     'insertafter' => 'Einfügen',
                     'createuser' => 'Benutzer',
@@ -148,7 +156,7 @@ $VAR1 = {
                     'rowsineffect' => 'betroffene Datensätze',
                     'edittable' => 'Tabelle bearbeiten.',
                     'sql' => 'SQL',
-                    'createdatabase' => 'Datenbank',
+                    'createdatabase' => 'Datenbanken',
                     'showdatabases' => 'Datenbanken',
                     'comment' => 'Kommentar',
                     'repair' => 'Reparieren',
@@ -157,8 +165,8 @@ $VAR1 = {
                     'name' => 'Name',
                     'endtable' => 'am ende',
                     'databases' => 'Datenbanken',
-                    'collation' => 'collation',
-                    'size' => 'size',
+                    'collation' => 'Collation',
+                    'size' => 'Größe',
                     'newentry' => 'Neuer Eintrag',
                     'edit' => 'Bearbeiten',
                     'wrong_passwort_text' => 'Das Passwort muss mindestens 6 zeichen lang sein',
@@ -168,8 +176,8 @@ $VAR1 = {
                     'editmysqluserrights' => 'Benutzerrechte',
                     'connect' => 'Verbinden',
                     'truncate' => 'Leeren',
-                    'table' => 'table',
-                    'type' => 'type',
+                    'table' => 'Tabelle',
+                    'type' => 'Type',
                     'optimize' => 'Optimieren',
                     'newcol' => 'Neue Zeile',
                     'show' => 'Anzeigen',
@@ -184,6 +192,14 @@ $VAR1 = {
                     'sqlsearch' => 'Suchen',                
                     'sqleditor' => 'Sql',
                     'new' => 'Neu',
+                    'ShowTableDetails' => 'Details',
+		    'DropTable'=> 'Tabellen',
+		    'DropDatabase'=> 'Datenbanken',
+		    'DeleteEntry'=> 'Tabelle',
+		    'SaveRights'=> 'Rechte',
+		    'codenotcheckedfileerror'=> '',
+		    'failednotindatabase'=> '',
+		    'failedinvalidcode'=> 'Falscher Code',
                   }
         };
 $lang =$VAR1;
\ No newline at end of file
