@@ -9,40 +9,11 @@ use DBI::Library qw(:all);
 use HTML::Menu::TreeView qw(:all);
 loadSettings("%PATH%/config/settings.pl");
 use Template::Quick;
-use HTML::Window qw(:all);
-my %parameter = (
-                 path   => "%PATH%/templates/",
-                 style  => "lze",
-                 server => "%host%",
-);
-use MySQL::Admin::Main qw(:all);
-initMain(
-         {
-          template => 'blog.htm',
-          path     => "%PATH%/templates/",
-          style    => "lze",
-          template => 'blog.htm'
-         }
-);
-initWindow(\%parameter);
-use HTML::TabWidget qw(:all);
-initTabWidget(
-              {
-               template => 'lzetabwidget.htm',
-               path     => "%PATH%/templates/",
-               style    => "lze",
-              }
-);
 use HTML::Menu::Pages;
-use HTML::Editor;
-use HTML::Editor::BBCODE;
 use DBI::Library::Database qw(:all);
 use MySQL::Admin::GUI;
 ### 3party
-use HTML::Entities;
-use CGI::QuickFormR;
-Syntax::Highlight::Engine::Kate;
-
+use URI::Escape;
 # Apache2 mod perl stuff
 # enable if the mod_perl 1.0 compatibility is needed
 use Apache2::compat ();
